quantizationtools.DistanceHeuristic
===================================

.. abjad-lineage:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic

.. autoclass:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__call__
      ~abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__eq__
      ~abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__format__
      ~abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__hash__
      ~abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__ne__
      ~abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__repr__

Bases
-----

- :py:class:`quantizationtools.Heuristic <abjad.tools.quantizationtools.Heuristic.Heuristic>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__hash__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic.__repr__
   :noindex:
